==> haskell-http-download-0.2.1.0-80-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-5EawQCrFjtEKKLJ4LDYvm7
key:                  http-download-0.2.1.0-5EawQCrFjtEKKLJ4LDYvm7
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  238dc7f6d59788377464721f926be80c
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-5EawQCrFjtEKKLJ4LDYvm7
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-IHt64Gotm2vFOEZhD5akU7
    bytestring-0.11.4.0 conduit-1.3.5-9fqCSsgtXVG2zpv5ZVEi4s
    conduit-extra-1.3.6-AEwfYIT97IN5iosArwGxsb
    crypton-0.34-9KzctTIsYlw5xU7XeDFfxs
    crypton-conduit-0.2.3-AnUWKsVS8esBwVrlWorZ4F directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    http-client-0.7.15-DQnyZx9lzoSgMdf26TxD3
    http-conduit-2.3.8.3-1nsQ6LY8l6ZCKHc2yiI82m
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    path-0.9.5-7WG724jmooVGZJtOHPJg6X
    path-io-1.8.1-Leg6ziIiXvX3dVe5KEzDcy
    retry-0.9.3.1-C8uZl6vhoJS4Eox3oNtCMg
    rio-0.1.22.0-D6FOCJ3nLjdCFbIFQSFA7I
    rio-prettyprint-0.1.6.0-5yGmMw90HGGCMMyAiyrtln

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-download-0.2.1.0-107-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-http-download.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-download
version:              0.2.1.0
visibility:           public
id:                   http-download-0.2.1.0-Hr09pEYTL558QLT10Rilb1
key:                  http-download-0.2.1.0-Hr09pEYTL558QLT10Rilb1
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/http-download#readme
synopsis:             Verified downloads with retries
description:
    Higher level HTTP download APIs include verification of content and retries

category:             Development
abi:                  3ce5ebeb9f5cc5b88bbbb5bc0c6498b7
exposed:              True
exposed-modules:      Network.HTTP.Download Network.HTTP.Download.Verified
hidden-modules:       Paths_http_download
import-dirs:          /usr/lib/ghc-9.2.8/site-local/http-download-0.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/http-download-0.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-download
hs-libraries:         HShttp-download-0.2.1.0-Hr09pEYTL558QLT10Rilb1
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj
    bytestring-0.11.4.0 conduit-1.3.6-6d8V4DJENsC1laAutlfv9x
    conduit-extra-1.3.6-GQSgUNMr0ZN9ENRzkRi4eD
    crypton-0.34-67uX59Sjjsw2dJbbUWUzWH
    crypton-conduit-0.2.3-5arhB9cdZ98ImjVBHxBMrf directory-1.3.6.2
    exceptions-0.10.4 filepath-1.4.2.2
    http-client-0.7.15-15pF87z30Lb260fGpQvD7x
    http-conduit-2.3.8.3-KkBMXrBtxP6LrN8a2mfNMZ
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    path-0.9.5-9124ykIABMXHDmnxFXSd3D
    path-io-1.8.1-3foXXaCW7usKFvWdR9fpTJ
    retry-0.9.3.1-4DkhyXQVdEO6NCSBFSc7an
    rio-0.1.22.0-CCynOv5jacWCBs6SD5CPpT
    rio-prettyprint-0.1.6.0-HC5utweDa8VL0DUiYO0v68

haddock-interfaces:
    /usr/share/doc/haskell-http-download/html/http-download.haddock

haddock-html:         /usr/share/doc/haskell-http-download/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
